==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/PasswordImportRequestDataContext.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.InlineHookRequestObject;
import com.okta.sdk.resource.model.PasswordImportRequestDataContextCredential;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * PasswordImportRequestDataContext
 */
@JsonPropertyOrder({ PasswordImportRequestDataContext.JSON_PROPERTY_REQUEST,
        PasswordImportRequestDataContext.JSON_PROPERTY_CREDENTIAL })
@JsonTypeName("PasswordImportRequestData_context")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class PasswordImportRequestDataContext implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_REQUEST = "request";
    private InlineHookRequestObject request;

    public static final String JSON_PROPERTY_CREDENTIAL = "credential";
    private PasswordImportRequestDataContextCredential credential;

    public PasswordImportRequestDataContext() {
    }

    public PasswordImportRequestDataContext request(InlineHookRequestObject request) {

        this.request = request;
        return this;
    }

    /**
     * Get request
     *
     * @return request
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_REQUEST)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public InlineHookRequestObject getRequest() {
        return request;
    }

    @JsonProperty(JSON_PROPERTY_REQUEST)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setRequest(InlineHookRequestObject request) {
        this.request = request;
    }

    public PasswordImportRequestDataContext credential(PasswordImportRequestDataContextCredential credential) {

        this.credential = credential;
        return this;
    }

    /**
     * Get credential
     *
     * @return credential
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CREDENTIAL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PasswordImportRequestDataContextCredential getCredential() {
        return credential;
    }

    @JsonProperty(JSON_PROPERTY_CREDENTIAL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setCredential(PasswordImportRequestDataContextCredential credential) {
        this.credential = credential;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PasswordImportRequestDataContext passwordImportRequestDataContext = (PasswordImportRequestDataContext) o;
        return Objects.equals(this.request, passwordImportRequestDataContext.request)
                && Objects.equals(this.credential, passwordImportRequestDataContext.credential);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(request, credential);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PasswordImportRequestDataContext {\n");
        sb.append("    request: ").append(toIndentedString(request)).append("\n");
        sb.append("    credential: ").append(toIndentedString(credential)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/PasswordImportRequestDataContext.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.InlineHookRequestObject;
import com.okta.sdk.resource.model.PasswordImportRequestDataContextCredential;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * PasswordImportRequestDataContext
 */
@JsonPropertyOrder({ PasswordImportRequestDataContext.JSON_PROPERTY_REQUEST,
        PasswordImportRequestDataContext.JSON_PROPERTY_CREDENTIAL })
@JsonTypeName("PasswordImportRequestData_context")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class PasswordImportRequestDataContext implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_REQUEST = "request";
    private InlineHookRequestObject request;

    public static final String JSON_PROPERTY_CREDENTIAL = "credential";
    private PasswordImportRequestDataContextCredential credential;

    public PasswordImportRequestDataContext() {
    }

    public PasswordImportRequestDataContext request(InlineHookRequestObject request) {

        this.request = request;
        return this;
    }

    /**
     * Get request
     *
     * @return request
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_REQUEST)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public InlineHookRequestObject getRequest() {
        return request;
    }

    @JsonProperty(JSON_PROPERTY_REQUEST)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setRequest(InlineHookRequestObject request) {
        this.request = request;
    }

    public PasswordImportRequestDataContext credential(PasswordImportRequestDataContextCredential credential) {

        this.credential = credential;
        return this;
    }

    /**
     * Get credential
     *
     * @return credential
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CREDENTIAL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PasswordImportRequestDataContextCredential getCredential() {
        return credential;
    }

    @JsonProperty(JSON_PROPERTY_CREDENTIAL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setCredential(PasswordImportRequestDataContextCredential credential) {
        this.credential = credential;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PasswordImportRequestDataContext passwordImportRequestDataContext = (PasswordImportRequestDataContext) o;
        return Objects.equals(this.request, passwordImportRequestDataContext.request)
                && Objects.equals(this.credential, passwordImportRequestDataContext.credential);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(request, credential);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PasswordImportRequestDataContext {\n");
        sb.append("    request: ").append(toIndentedString(request)).append("\n");
        sb.append("    credential: ").append(toIndentedString(credential)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
